Crate asset_procmac

Crate asset_procmac 

Some i/o macros that help with applications that need assets, by importing them using normal FS in debug builds, but directly embedding the data in the application in release builds.

Macros

include_if_release
Makes the contents of a file built into the executable on release builds, but dynamically reads the file at runtime in debug builds. This is handy because it removes the need to recompile every time an asset changes, but still gives you the benefits of having built-in assets.
include_if_release_bytes
See include_if_release.
Same thing, but reads bytes.